@@ -1,11 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "json-par" "5.0.0"
+(define-package "json-par" "5.1.0"
   "Minor mode for structural editing of JSON."
-  '((emacs     "24.4")
-    (json-mode "1.7.0"))
+  '((emacs "24.4"))
   :url "https://github.com/taku0/json-par"
-  :commit "7b346b0f0db62d65f382ce48a9b2ecd9e180b0d7"
-  :revdesc "7b346b0f0db6"
+  :commit "1c0e363a8d28bf66187d082c97370c2fa11adfcc"
+  :revdesc "1c0e363a8d28"
   :keywords '("abbrev" "convenience" "files")
   :authors '(("taku0" . "mxxouy6x3m_github@tatapa.org"))
   :maintainers '(("taku0" . "mxxouy6x3m_github@tatapa.org")))
