@@ -4,9 +4,9 @@
 ;;
 ;; Author: taku0 <mxxouy6x3m_github@tatapa.org>
 ;; Maintainer: taku0 <mxxouy6x3m_github@tatapa.org>
-;; Package-Version: 5.0.0
-;; Package-Revision: 7b346b0f0db6
-;; Package-Requires: ((emacs "24.4") (json-mode "1.7.0"))
+;; Package-Version: 5.1.0
+;; Package-Revision: 1c0e363a8d28
+;; Package-Requires: ((emacs "24.4"))
 ;; Keywords: abbrev, convenience, files
 ;; URL: https://github.com/taku0/json-par
 
@@ -64,7 +64,6 @@
 ;;; Code:
 
 (require 'easymenu)
-(require 'json-mode)
 (require 'json-par-utils)
 (require 'json-par-keymap)
 (require 'json-par-lexer)
@@ -199,6 +198,7 @@ Call `json-par--post-newline' after line break."
     (define-key map (kbd "S-TAB") #'json-par-mark-head-of-member)
     (define-key map "\\" #'json-par-insert-reverse-solidus)
     (json-par-define-special-key map ";" #'json-par-dwim)
+    (json-par-define-special-key map "u" #'universal-argument)
     (easy-menu-define json-par-menu map "Show a menu for JSON Par mode."
       `("JSON Par"
         :help "Structural editing of JSON"
